@@ -16,6 +16,8 @@ var (
 	newlineBytes               = []byte("\n")
 	starBytes                  = []byte("*")
 	plusBytes                  = []byte("+")
+	plusPlusBytes              = []byte("++")
+	minMinBytes                = []byte("--")
 	expBytes                   = []byte("**")
 	bitOrBytes                 = []byte("|")
 	colonBytes                 = []byte(":")
@@ -1370,20 +1372,18 @@ func removeUnderscoresAndSuffix(b []byte) ([]byte, bool) {
 	return b, false
 }
 
-func decimalNumber(b []byte, prec int) []byte {
-	var suffix bool
-	b, suffix = removeUnderscoresAndSuffix(b)
+func decimalNumber(num []byte, prec int) []byte {
+	b, suffix := removeUnderscoresAndSuffix(num)
 	if suffix {
 		return append(b, 'n')
 	}
 	return minify.Number(b, prec)
 }
 
-func binaryNumber(b []byte, prec int) []byte {
-	var suffix bool
-	b, suffix = removeUnderscoresAndSuffix(b)
+func binaryNumber(num []byte, prec int) []byte {
+	b, suffix := removeUnderscoresAndSuffix(num)
 	if len(b) <= 2 || 65 < len(b) {
-		return b
+		return num
 	}
 	var n int64
 	for _, c := range b[2:] {
@@ -1403,11 +1403,10 @@ func binaryNumber(b []byte, prec int) []byte {
 	return minify.Number(b, prec)
 }
 
-func octalNumber(b []byte, prec int) []byte {
-	var suffix bool
-	b, suffix = removeUnderscoresAndSuffix(b)
+func octalNumber(num []byte, prec int) []byte {
+	b, suffix := removeUnderscoresAndSuffix(num)
 	if len(b) <= 2 || 23 < len(b) {
-		return b
+		return num
 	}
 	var n int64
 	for _, c := range b[2:] {
@@ -1427,11 +1426,10 @@ func octalNumber(b []byte, prec int) []byte {
 	return minify.Number(b, prec)
 }
 
-func hexadecimalNumber(b []byte, prec int) []byte {
-	var suffix bool
-	b, suffix = removeUnderscoresAndSuffix(b)
+func hexadecimalNumber(num []byte, prec int) []byte {
+	b, suffix := removeUnderscoresAndSuffix(num)
 	if len(b) <= 2 || 12 < len(b) || len(b) == 12 && ('D' < b[2] && b[2] <= 'F' || 'd' < b[2]) {
-		return b
+		return num
 	}
 	var n int64
 	for _, c := range b[2:] {
